/***************************************************************
 * Name:      wx019Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2025-04-20
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#ifdef __BORLANDC__
#pragma hdrstop
#endif //__BORLANDC__

#include "wx019Main.h"
#include "RearrangeList.h"
#include "RearrangeCtrl.h"
#include "EditableListBox.h"
#include "AddRemoveCtrl.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx019Frame, wxFrame)
    EVT_CLOSE(wx019Frame::OnClose)
    EVT_MENU(idMenuQuit, wx019Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx019Frame::OnAbout)
    EVT_MENU(idMenuRearrangeList, wx019Frame::OnRearrangeList)
    EVT_MENU(idMenuRearrangeCtrl, wx019Frame::OnRearrangeCtrl)
    EVT_MENU(idMenuEditableListBox, wx019Frame::OnEditableListBox)
    EVT_MENU(idMenuAddRemoveCtrl, wx019Frame::OnAddRemoveCtrl)
END_EVENT_TABLE()

wx019Frame::wx019Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title)
{
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idMenuRearrangeList, _T("wxRearrange&List"), _T("Control wxRearrangeList"));
    fileMenu->Append(idMenuRearrangeCtrl, _T("wxRearrange&Ctrl"), _T("Control wxRearrangeCtrl"));
    fileMenu->Append(idMenuEditableListBox, _T("wx&EditableListBox"), _T("Control wxEditableListBox"));
    fileMenu->Append(idMenuAddRemoveCtrl, _T("wx&AddRemoveCtrl"), _T("Control wxAddRemoveCtrl"));
    fileMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Salir de la aplicación"));
    mbar->Append(fileMenu, _("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _T("&Sobre\tF1"), _T("Muestra información sobre esta aplicación"));
    mbar->Append(helpMenu, _T("&Ayuda"));

    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_T("Hola"),0);
    SetStatusText(wxbuildinfo(short_f), 1);

    datos.orden.push_back(~1);
    datos.orden.push_back(5);
    datos.orden.push_back(2);
    datos.orden.push_back(~6);
    datos.orden.push_back(~3);
    datos.orden.push_back(0);
    datos.orden.push_back(~4);

    datos.items.push_back(_T("Primero"));
    datos.items.push_back(_T("Segundo"));
    datos.items.push_back(_T("Tercero"));
    datos.items.push_back(_T("Cuarto"));
    datos.items.push_back(_T("Quinto"));
    datos.items.push_back(_T("Sexto"));
    datos.items.push_back(_T("Séptimo"));
}


wx019Frame::~wx019Frame()
{
}

void wx019Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx019Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx019Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _T("Vienvenido a ..."));
}

void wx019Frame::OnRearrangeList(wxCommandEvent &event)
{
    RearrangeList *dlg = new RearrangeList(this, datos);
    dlg->ShowModal();
}

void wx019Frame::OnRearrangeCtrl(wxCommandEvent &event)
{
    RearrangeCtrl *dlg = new RearrangeCtrl(this, datos);
    dlg->ShowModal();
}

void wx019Frame::OnEditableListBox(wxCommandEvent &event)
{
    EditableListBox *dlg = new EditableListBox(this, datos);
    dlg->ShowModal();
}

void wx019Frame::OnAddRemoveCtrl(wxCommandEvent &event)
{
    AddRemoveCtrl *dlg = new AddRemoveCtrl(this, datos);
    dlg->ShowModal();
}
